@@ -26,17 +26,25 @@
 
 #define MAX_SWAPFILES 8
 
+struct load {
+  unsigned long total;
+  unsigned long user;
+  unsigned long system;
+  unsigned long nice;
+  unsigned long idle;
+};
+
 struct meminfo {
   int total;
-  int used;
   int cache;
+  int buffers;
   int free;
   int shared;
 };
 
 extern void get_meminfo( int *, struct meminfo * );
-extern double get_load(void);
-extern double get_idle(void);
+extern double get_loadavg(void);
+extern void get_load(struct load *);
 extern int sysinfo_init(void);
 
 #endif
